//
//  Standard includes
//
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>

//
// Scheduler includes
//
#include "FreeRTOS.h"
#include "task.h"

//
//  Demo application includes
//
#include "main.h"
#include "adc/adc.h"
#include "cpu/cpu.h"
#include "eints/eints.h"
#include "gps/gps.h"
#include "leds/leds.h"
#include "monitor/monitor.h"
#include "rtc/rtc.h"
#include "sensors/sensors.h"
#include "uart/uart.h"
#include "usb/usb.h"

//
//
//
xTaskHandle taskHandles [TASKHANDLE_LAST];

//
//
//
int main (void)
{
	cpuSetupHardware ();
	uartInit (0, 115200, 64);
	uartInit (1, 4800, 64);
  usbInit ();
  rtcInit ();
  adcInit ();
  eintsInit ();

  memset (taskHandles, 0, sizeof (taskHandles));

  //
  //  This causes stdio to allocate buffers in the main area instead of on the task stack
  //
  printf ("LPC-P2148 Demo, Version 1.00, " __DATE__ ", " __TIME__ "\n");

	xTaskCreate (vSensorsTask,  (const signed portCHAR * const) "Sensors",  512,                      NULL, (configMAX_PRIORITIES - 2), &taskHandles [TASKHANDLE_SENSORS]);
	xTaskCreate (vGPSTask,      (const signed portCHAR * const) "GPS",      768,                      NULL, (tskIDLE_PRIORITY + 1),     &taskHandles [TASKHANDLE_GPS]);
	xTaskCreate (vMonitorTask,  (const signed portCHAR * const) "Monitor",  1024,                     NULL, (tskIDLE_PRIORITY + 1),     &taskHandles [TASKHANDLE_MONITOR]);
  xTaskCreate (vLEDFlashTask, (const signed portCHAR * const) "LEDx",     configMINIMAL_STACK_SIZE, NULL, (tskIDLE_PRIORITY + 1),     &taskHandles [TASKHANDLE_LED]);
	vTaskStartScheduler ();

	return 0;
}
